summaryrefslogtreecommitdiff
path: root/chart2
diff options
context:
space:
mode:
authorNoel Grandin <noel@peralex.com>2015-04-16 15:41:10 +0200
committerNoel Grandin <noel@peralex.com>2015-04-22 10:28:39 +0200
commit0578aa4de27cc960cd3709eb2e15f40e02e1272d (patch)
tree295966c066e2760f4322273d970fa02fe5e0c84a /chart2
parentf87e0957cdcbf9ee12e0615b55a1bb1de1d70efb (diff)
convert BROWSER_ constants to scoped enum
and fix a couple of places where it was mixing these flags up with the WinBits flags and calling the wrong constructor. Change-Id: I65c66bdd5a263e2f1db179c853f3f00e9ac7659e
Diffstat (limited to 'chart2')
-rw-r--r--chart2/source/controller/dialogs/DataBrowser.cxx14
1 files changed, 7 insertions, 7 deletions
diff --git a/chart2/source/controller/dialogs/DataBrowser.cxx b/chart2/source/controller/dialogs/DataBrowser.cxx
index f430d3723fce..7fae410c9c4e 100644
--- a/chart2/source/controller/dialogs/DataBrowser.cxx
+++ b/chart2/source/controller/dialogs/DataBrowser.cxx
@@ -52,23 +52,23 @@
#include <algorithm>
#include <functional>
/* BROWSER_COLUMNSELECTION : single cells may be selected rather than only
entire rows
BROWSER_(H|V)LINES : show horizontal or vertical grid-lines
BROWSER_AUTO_(H|V)SCROLL : scroll automated horizontally or vertically when
cursor is moved beyond the edge of the dialog
- BROWSER_HIGHLIGHT_NONE : Do not mark the current row with selection color
+ BrowserMode::HIDESELECT : Do not mark the current row with selection color
(usually blue)
*/
#define BROWSER_STANDARD_FLAGS \
- BROWSER_COLUMNSELECTION | \
- BROWSER_HLINES | BROWSER_VLINES | \
- BROWSER_AUTO_HSCROLL | BROWSER_AUTO_VSCROLL | \
- BROWSER_HIGHLIGHT_NONE
+ BrowserMode::COLUMNSELECTION | \
+ BrowserMode::HLINES | BrowserMode::VLINES | \
+ BrowserMode::AUTO_HSCROLL | BrowserMode::AUTO_VSCROLL | \
+ BrowserMode::HIDESELECT
-// BROWSER_HIDECURSOR would prevent flickering in edit fields, but navigating
+// BrowserMode::HIDECURSOR would prevent flickering in edit fields, but navigating
// with shift up/down, and entering non-editable cells would be problematic,
// e.g. the first cell, or when being in read-only mode
@@ -52,23 +52,23 @@
#include <algorithm>
#include <functional>
-/* BROWSER_COLUMNSELECTION : single cells may be selected rather than only
+/* BrowserMode::COLUMNSELECTION : single cells may be selected rather than only
entire rows
BROWSER_(H|V)LINES : show horizontal or vertical grid-lines